length_dist_simulation: Vector containing VDJ length distributions

length_dist_simulationR Documentation

Vector containing VDJ length distributions

Description

A vector containing 10000 VDJ lengths for simulating of fully random sequences (independent of germline genes)

Usage

length_dist_simulation

Format

A vector with 10000 entries:

length

VDJ nucleotide lengths sampled from murine naive follicular B-cell data, Greiff 2017

https://doi.org/10.1016/j.celrep.2017.04.054


GreiffLab/immuneSIM documentation built on Dec. 2, 2023, 1:22 a.m.