shm_event_reconstruction: Decodes immuneSIM repertoire shm_events column.

View source: R/shm_event_reconstruction.R

shm_event_reconstructionR Documentation

Decodes immuneSIM repertoire shm_events column.

Description

Decodes immuneSIM repertoire shm_events column.

Usage

shm_event_reconstruction(shm_event_vec)

Arguments

shm_event_vec

An vector containing strings describing SHM events as output in shm_events column of immuneSIM repertoires. The string contains information on every mutation event in the form:

"Position:pre_mutation_nucleotide,post_mutation_nucleotide" combined as: "Mutation1|Mutation2|Mutation3". For example: "171:t,a|186:g,a".

Value

List of dataframes. Each entry contains location and shm mutation info for a simulated sequence

Examples

shm_events_example<-c("171:t,a|186:g,a|287:g,a|310:t,c","","294:c,g|316:t,c|330:c,t")
shm_list<-shm_event_reconstruction(shm_events_example)

GreiffLab/immuneSIM documentation built on Dec. 2, 2023, 1:22 a.m.