| length_dist_simulation | R Documentation |
A vector containing 10000 VDJ lengths for simulating of fully random sequences (independent of germline genes)
length_dist_simulation
A vector with 10000 entries:
VDJ nucleotide lengths sampled from murine naive follicular B-cell data, Greiff 2017
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.